<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam" :inline="true">
        <el-form-item label="地区">
          <el-input
            clearable
            placeholder="请输入地区"
            v-model="querys[0].value"
          />
        </el-form-item>
        <el-form-item label="路径">
          <el-input
            clearable
            placeholder="请输入路径"
            v-model="querys[1].value"
          />
        </el-form-item>
        <el-form-item label="时区">
          <el-input
            clearable
            placeholder="请输入时区"
            v-model="querys[2].value"
          />
        </el-form-item>
        <el-form-item>
          <el-button type="primary" icon="el-icon-search" @click="handleSearch"
            >搜索</el-button
          >
          <el-button icon="el-icon-refresh" @click="handleReset"
            >重置</el-button
          >
        </el-form-item>
      </el-form>
    </div>
    <div class="bbsl-table-content" ref="contentPanel">
      <div class="bbsl-btn-content" ref="btnPanel">
        <el-button icon="el-icon-plus" type="primary" @click="handleAdd"
          >新增</el-button
        >
        <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
          <el-button
            slot="reference"
            :disabled="!multipleSelection.length"
            icon="el-icon-delete"
            type="danger"
            style="margin-left: 10px"
            >删除</el-button
          >
        </el-popconfirm>
      </div>
      <el-table
        border
        size="mini"
        v-loading="loading"
        ref="multipleSelection"
        :data="tableData"
        :style="{width: '100%'}"
        :max-height="tableMaxHeight"
        :cell-style="{'text-align': 'center'}"
        :header-cell-style="{'text-align': 'center'}"
        @row-dblclick="handleDbClick"
        @selection-change="handleSelectionChange"
      >
        <el-table-column type="selection" width="55"></el-table-column>
        <el-table-column
          fixed
          type="index"
          width="55"
          label="序号"
        ></el-table-column>

        <el-table-column
          fixed
          sortable
          prop="id"
          label="id"
          show-overflow-tooltip
        ></el-table-column>

        <el-table-column
          fixed
          sortable
          prop="name"
          label="地区"
          show-overflow-tooltip
        ></el-table-column>

        <el-table-column
          fixed
          sortable
          prop="path"
          label="路径"
          show-overflow-tooltip
        ></el-table-column>

        <el-table-column
          fixed
          sortable
          prop="timezone"
          label="时区"
          show-overflow-tooltip
        ></el-table-column>

        <el-table-column
          fixed
          sortable
          prop="timezoneOffset"
          label="时区偏移"
          show-overflow-tooltip
        ></el-table-column>

        <el-table-column
          fixed
          sortable
          prop="text"
          label="天气现象"
          show-overflow-tooltip
        ></el-table-column>

        <el-table-column
          fixed
          sortable
          prop="code"
          label="天气现象编码"
          show-overflow-tooltip
        ></el-table-column>

        <el-table-column
          fixed
          sortable
          prop="temperature"
          label="温度"
          show-overflow-tooltip
        ></el-table-column>

        <el-table-column
          fixed
          sortable
          prop="lastUpdate"
          label="来源更新时间"
          show-overflow-tooltip
        ></el-table-column>

        <el-table-column
          fixed
          sortable
          prop="insertTime"
          label="中台插入时间"
          show-overflow-tooltip
        ></el-table-column>

        <el-table-column
          fixed
          sortable
          prop="updateTime"
          label="中台更新时间"
          show-overflow-tooltip
        ></el-table-column>
      </el-table>
      <el-pagination
        align="right"
        background
        class="bbsl-pagination"
        ref="paginationPanel"
        @size-change="handleSizeChange"
        @current-change="handleCurrentChange"
        :current-page="queryParam.pageBean.page"
        :page-sizes="[20, 30, 40, 50]"
        :page-size="queryParam.pageBean.pageSize"
        layout="total, sizes, prev, pager, next, jumper"
        :total="total"
      ></el-pagination>
    </div>
    <DwdSjWeatherPhenoMiFormDialog
      ref="formModal"
    ></DwdSjWeatherPhenoMiFormDialog>
  </div>
</template>

<script>
import {TableMixin} from '@/mixins/tableMixin'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import dictContracts from '@/components/dict/DictSelectUtils.js'

import DwdSjWeatherPhenoMiApi from '@/views/Manage/dwd/api/DwdSjWeatherPhenoMiApi'
import DwdSjWeatherPhenoMiFormDialog from '@/views/Manage/dwd/components/DwdSjWeatherPhenoMiFormDialog'

export default {
  name: 'DwdSjWeatherPhenoMiManage',
  components: {
    DwdSjWeatherPhenoMiFormDialog
  },
  mixins: [TableMixin],
  data() {
    return {
      url: {
        delete: '/manager/dwdSjWeatherPhenoMi/delete'
      },
      querys: [
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'name',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'path',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'timezone',
          relation: 'AND',
          value: ''
        }
      ],
      StshowFormDias: false,
      fuelTypes: []
    }
  },
  created() {},
  mounted() {},
  methods: {
    // 重置
    clearQuerys() {
      this.querys[0].value = ''
      this.querys[1].value = ''
      this.querys[2].value = ''
    },
    // 获取list
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      if (this.querys[2].value) {
        this.queryParam.querys.push(this.querys[2])
      }
      DwdSjWeatherPhenoMiApi.loadDwdSjWeatherPhenoMi(this.queryParam, res => {
        //console.log(res, 'res')
        this.total = res.total
        this.tableData = res.rows
        this.$set(this.tableData)
        this.loading = false
      })
    },
    // 修改
    handleUpdate(row) {
      console.log(row.id)
      this.$refs.formModal.Update(row)
    },
    // 关联设备
    // handleClick(item) {
    //   console.log(item.id)
    //   this.StshowFormDias = true
    // },
    closeStshowForm() {
      this.StshowFormDias = false
    }
  }
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}
</style>
